use super::{RawDhcpOption, DhcpOptionError};
use crate::options::DhcpOption;
use core::net::Ipv4Addr;

pub struct ResourceLocationServerOption;

impl DhcpOption for ResourceLocationServerOption {
    const CODE: u8 = 11;
    type Item = Vec<Ipv4Addr>;

    fn parse(option: &RawDhcpOption) -> Result<Self::Item, DhcpOptionError> {
        let rem = option.length % 4;
        (rem == 0)
            .then_some(())
            .ok_or(DhcpOptionError::InvalidLength(option.length, option.length + 4 - rem))?;
        Ok(option
            .data
            .chunks(4)
            .map(|c| Ipv4Addr::new(c[0], c[1], c[2], c[3]))
            .collect())
    }
}
