use super::{DhcpOptionError, RawDhcpOption};
use crate::options::DhcpOption;
use core::net::Ipv4Addr;

pub struct SubnetMask;

impl DhcpOption for SubnetMask {
    const CODE: u8 = 1;
    type Item = Ipv4Addr;

    fn parse(option: &RawDhcpOption) -> Result<Self::Item, DhcpOptionError> {
        (option.length == 4)
            .then_some(())
            .ok_or(DhcpOptionError::InvalidLength(option.length, 4))?;
        Ok(Ipv4Addr::new(
            option.data[0],
            option.data[1],
            option.data[2],
            option.data[3],
        ))
    }
}
